/*
 * Copyright (c) 2006-2017 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.config.profiles;

import com.google.auto.value.AutoValue;

import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

/**
 * Describes a profile, used to describe the settings associated with the local client on a
 * connection.
 */
@AutoValue
public abstract class Profile {

    Profile() {}

    public abstract String getName();

    public abstract String getRealname();

    public abstract Optional<String> getIdent();

    public abstract List<String> getNicknames();

    public abstract Collection<String> getHighlights();

    public static Profile create(final String name, final String realName,
            final Optional<String> ident, final List<String> nicknames) {
        return create(name, realName, ident, nicknames, Collections.emptyList());
    }

    public static Profile create(final String name, final String realName,
            final Optional<String> ident, final List<String> nicknames,
            final Collection<String> highlights) {
        return new AutoValue_Profile(name, realName, ident, nicknames, highlights);
    }

}
